function [inv_R,Aref] = inv_SPCA_2(dat,R,init_param)

%
% inv_SPCA computes the inverse of one sample (R) from the SPCA
% representation back into the input space (pto_proximo). 
%
% USE:
% [pto_proximo,Aref] = inv_SPCA(dat,R,init_param)
%
% Inputs:
%
%   dat         = data D*N matrix (D = dimension, N= number of samples)
%   R           = column vector to be inverted
%   init_param  = initialization parameters (see initialize_SPCA.m)
%
% Outputs:
%
%   inv_R = inverted R point 
%   Aref  = reference matrix in inv_R (internal use)
%

pto_origen = init_param.origin;
Aref = init_param.Aref;
Nbins = init_param.Nbins;
Nv = init_param.k;
muelle = init_param.q;
dist_fuera = init_param.dist_out;


tau = init_param.tau;
eje_principal = init_param.PC;
CRIT = init_param.CRIT;
inv_R_principal = init_param.points_on_PC;
resp_principal = init_param.first_responses;

[DIM N] = size(dat);

direc = 1;
eje = eje_principal;

%%%%%%%%%%%%%%%%%%%%%%%%
n1 = find(cat(1,eje(:).ref)==fix(R(direc)));
n2 = find(cat(1,eje(:).ref)==sign(R(direc))+fix(R(direc)));

if isempty(n1),
    n1 = find(cat(1,eje(:).ref) == sign(R(direc))*max(sign(R(direc))*cat(1,eje(:).ref)));
end
pto1 = eje(n1(1)).pto;
if isempty(n2),
    pto2 = pto1;
else
    pto2 = eje(n2(1)).pto;
end

vect21 = pto2-pto1;
dec = abs(R(direc)-fix(R(direc)));
[inv_R] = pto1 + dec*vect21;
pto_origen = inv_R;
Aref = eje(n1(1)).V_der;

EG(1).eje = eje_principal;
ptos = dat;
Nvn = Nv;
for direc = 2:DIM

    clear resp ptos_proximo
    if direc == 2
        inv_R = inv_R_principal;
        resp = resp_principal;
    else
        inv_R = zeros(size(ptos));
        resp = zeros(1,size(ptos,2));
        for n=1:size(ptos,2)
            [inv_R(:,n),resp(:,n)] = punto_en_eje_NLPCA(ptos(:,n),eje);
        end
    end

    aux_res = abs(resp-R(direc-1));
    [sss iii] = sort(aux_res);
    Nvn = round(Nvn/2);
    ptos = dat(:,iii(1:5*Nvn));
    
    eje = lanza_axis(dat,pto_origen,Aref,direc,ptos,Nvn,tau,muelle,dist_fuera);
    EG(direc).eje = eje;

    d = zeros(1,size(dat,2));
    for n=1:size(dat,2)
        d(n) = dist_pto_a_ejes(dat(:,n),eje);
    end

    for nn=1:direc-1, qqq(nn) = length(EG(nn).eje);end
    
    [ss ii] = sort(d);
    Npoints = min(round(size(ptos,2)*0.85),length(ii));
    dat_tubo = dat(:,ii(1:Npoints));
    
    eje = modifica_axis(dat,eje,pto_origen,dat_tubo,Nbins(direc),Aref,0,Nvn,CRIT);

    n1 = find(cat(1,eje(:).ref)==fix(R(direc)));
    n2 = find(cat(1,eje(:).ref)==sign(R(direc))+ fix(R(direc)));
    if isempty(n1),
        n1 = find(cat(1,eje(:).ref) == sign(R(direc))*max(sign(R(direc))*cat(1,eje(:).ref)));
    end
    pto1 = eje(n1(1)).pto;
    if isempty(n2),
        pto2 = pto1;
    else pto2 = eje(n2(1)).pto;
    end

    vect21 = pto2-pto1;
    dec = abs(R(direc)-fix(R(direc)));
    
    [inv_R] = pto1 + dec*vect21;     
    
    Aref = eje(n1(1)).V_der;
     pto_origen = inv_R;

end



