
function [pto_proximo2 R2 pto_proximo1 R1 EE] = spca_2_convergencia(dat,pto_test,init_param,tol)

%
% SPCA_2_convergencia is a modified version of SPCA_2 that returns the evolution
% of the reconstruction error as a function of the iteration.
%
% USE:
% [inverse2 response2 inverse1 response1 ERRORS] = spca(dat,test_sample,init_param,tol)
%
%    dat = Training dataset (D*N matrix, where D is the dimensionality and
%          N is the number of samples)
%
%    test_sample = D*1 column vector with the sample
%
%    init_param = initialization parameters as given by initialize_SPCA_2.m 
%
%    tol = tolerance for the reconstruction error in the inverse
%          This is given in Euclidean distance in the input space. 
%          A very small tolerance may require a large number of iterations 
%          (now fixed at 20 in this routine).
%
%    response2 = SPCA transform of the test sample 
%                with the selected (eventually non-Euclidean) criterion 
%
%    inverse2 = inverse of the test sample in the input space
%                with the selected (eventually non-Euclidean) criterion 
%
%    response1 = SPCA transform of the test sample 
%                with Euclidean criterion 
%
%    inverse1 = inverse of the test sample in the input space
%                with Euclidean criterion 
%
%    ERRORS = vector with the reconstruction error in each iteration of the
%             SPCA algorithm
%


Nv = init_param.k;

[R pto_proximo A_ref] = response_SPCA(dat,pto_test,init_param);

error = rmse(pto_proximo,pto_test);

EE(1) = error;

nn=1;
while error>tol

    [V_izq,V_der,V_ref] = local_axes(dat,pto_proximo,A_ref,Nv);
    
    proy = proyecta_en_dos_ejes(pto_test,pto_proximo,V_izq,V_der);
    R = R + 0.01*proy';
    
    [pto_proximo,A_ref] = inv_SPCA_eucl(dat,R,init_param);
    error = rmse(pto_proximo,pto_test);
    
     RR(:,nn) = R;
     PP(:,nn) = pto_proximo;
     EE(nn) = error;
     nn = nn+1;

     if nn>20
         [mm ii] = min(EE);
         R = RR(:,ii);
         pto_proximo = PP(:,ii);
         break
     end
     
end

R1 = R;
pto_proximo1 = pto_proximo;

EJ = modifica_axes_2(dat,R1,init_param);
EJ(1,1).eje  = init_param.PC;

for n2 = 1:size(pto_test,1)
    [pto_proximo2b,R2(n2,1)] = punto_en_eje_NLPCA(EJ(1,n2).pto_proyeccion,EJ(1,n2).eje);
end

[pto_proximo2,Aref2] = inv_SPCA_2(dat,R2,init_param);


